;; Generated package description from keymap-popup.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "keymap-popup" "0.1.0.0.20260427.171813" "Described keymaps with popup help" '((emacs "29.1")) :commit "4ffa637cb55119305c7a897dabe7e4e475d38cc8" :keywords '("convenience") :url "https://codeberg.org/thanosapollo/emacs-keymap-popup")
